@@ -2,37 +2,33 @@
 #define __el__audio_h
 
 #include <iostream>
+#include "release.h"
 
-namespace el3 {
+namespace PRJID {
 
 
 typedef enum E_AudioSample {
 	AS_NONE,
 	AS_TITLE,
 	AS_FAILED,
-	AS_PASSED,
-	AS_EXPLOSION,
-	AS_PROBLEM,
+	AS_EXPLOSION_BUILDING,
+	AS_EXPLOSION_PLANE,
 	AS_LASER,
 	AS_JETPACK,
-	AS_PICK,
-	AS_HURT,
+	AS_PROBLEM,
 	AS_LAST
 };
 
 typedef enum E_AudioChannel {
 	AC_NEXT=-1,
 	AC_TITLE,
-	AC_LASER,
 	AC_PROBLEM,
-	AC_JETPACK,
-	AC_PICK,
-	AC_HURT,
-	AC_DAMAGED,
+	AC_LASER,
 	AC_EXPLOSION,
 	AC_EXPLOSION2,
 	AC_EXPLOSION3,
 	AC_EXPLOSION4,
+	AC_EXPLOSION5,
 	AC_LAST
 };
 
@@ -51,6 +47,7 @@ public:
 	static void schedule_play(unsigned int delay,E_AudioSample s,E_AudioChannel chan=AC_NEXT,int repeat=0);
 };
 
+std::ostream& operator<<(std::ostream&s, Audio);
 
 } //namespace
 
