@@ -2,7 +2,7 @@
 
 #include "config.h"
 
-namespace el3 {
+namespace PRJID {
 
 
 bool mouse_reverse_=false;
@@ -27,6 +27,12 @@ void Config::resolution(unsigned int x,unsigned int y) {
 unsigned int Config::dx() { return dx_; }
 unsigned int Config::dy() { return dy_; }
 
+unsigned int Config::cx() { return dx_/2; }
+unsigned int Config::cy() { return dy_/2; }
+
+unsigned int Config::tx() { return dx_/3; }
+unsigned int Config::ty() { return dy_/3; }
+
 
 bool record_=false;
 
@@ -47,30 +53,4 @@ void Config::toggle_show_gun() {
 	show_gun_=!show_gun_;
 }
 
-int league_=0;
-int Config::league() {
-	return league_;
-}
-void Config::set_league(int l) {
-	league_=l;
-}
-
-std::string name_="anon";
-
-std::string Config::name() {
-	return name_;
-}
-void Config::set_name(std::string n) {
-	if (n=="") return;
-	name_=n;
-}
-
-bool offline_=false;
-bool Config::offline() {
-	return offline_;
-}
-void Config::set_offline(bool b) {
-	offline_=b;
-}
-
 } //namespace
