@@ -1,9 +1,11 @@
-#ifndef __el3__config_h
-#define __el3__config_h
+#ifndef __el__config_h
+#define __el__config_h
 
 #include <iostream>
 
-namespace el3 {
+#include "release.h"
+
+namespace PRJID {
 
 
 class Config {
@@ -19,6 +21,13 @@ public:
 	static unsigned int dx();
 	static unsigned int dy();
 
+   static unsigned int cx();
+   static unsigned int cy();
+
+   static unsigned int tx();
+   static unsigned int ty();
+
+
 
 	static bool record();
 	static void toggle_record();
@@ -26,16 +35,6 @@ public:
 	static bool show_gun();
 	static void toggle_show_gun();
 
-
-	static int league();
-	static void set_league(int l);
-
-	static std::string name();
-	static void set_name(std::string n);
-
-
-	static bool offline();
-	static void set_offline(bool b);
 };
 
 
