@@ -2,6 +2,7 @@
 #define __el__container_h
 
 #include <iostream>
+#include <vector>
 #include <list>
 
 #include "entitytype.h"
@@ -21,11 +22,13 @@ public:
 	Container();
 	~Container();
 
+
 	void clear();
 	void remove(unsigned int i);
 
 	void add(Entity *e,bool special=false);
 
+
 	void set_game(Game *g);
 	
 	void act(unsigned int ticks);
@@ -33,8 +36,8 @@ public:
 
 	void draw();
 
-	Entity *select(int x,int y);
-	Entity *select_single(int x,int y);
+
+	bool collision_with_plane(C3f p,float rad);
 
 	Entity *create(e_entitytype t);
 };
