@@ -1,5 +1,5 @@
-#ifndef __el3__entity_h
-#define __el3__entity_h
+#ifndef __el__entity_h
+#define __el__entity_h
 
 #include <iostream>
 #include <vector>
@@ -7,66 +7,60 @@
 #include "coordinate.h"
 #include "entitytype.h"
 #include "tweak/tweak.h"
+#include "position.h"
 
-namespace el3 {
+#include "release.h"
+
+namespace PRJID {
 
 class Container;
 class Game;
 
 class Entity {
+	bool collision;
+	bool collision_y;
 
 	C3f dest;
 	Entity * mdest;
-	float destroty;
 	Container *container_;
 	Game *game_;
 	unsigned int exploding;
-	unsigned int lastnewdest;
 
-	bool snap();
 	void init();
-	void lookatdest();
-	bool trymove(C3f d);
-	bool trymove_single(C3f d);
-
-	C3 collision;
-
+	int ttl;
 	float speed;
 
 	bool m_forward,m_backward,m_left,m_right;
-	e_entitytype type;
-public:
-	bool remove;
-	
-
-	C3f rot;
-	C3f pos;
-	C3f dir;
-
 	unsigned int myticks;
-
 	unsigned int jumping;
+public:
+	Position position;
+	e_entitytype type;
+	bool remove;
 
 	Entity();
 
-	void set_type(e_entitytype t);
+
+	C3f get_position() const;
+	void set_position(C3f p);
+	//C3f get_rotation() const;
+
 	void set_container(Container *c) { container_=c; }
 	void set_game(Game *g) { game_=g; }
 
-	e_entitytype get_type();
-
 	void draw();
 	bool isactive();
-	
 
-	C3f gunpos();
+	void set_type(e_entitytype type);
+	
 
 	void act(unsigned int ticks);
 	void tick(unsigned int ticks);
+	bool trymove(C3f d);
 
-	void new_dest();
 	void hit();
 	void explode();
+	void drop_bomb();
 
 	void move_direction(C3f r,float mod=1.0f);
 	void move_forward(float mod=1.0f);
@@ -88,6 +82,7 @@ public:
 
 	void jump();
 
+	Entity *clone();
 };
 
 
