@@ -1,11 +1,13 @@
-#ifndef __el3__help_h
-#define __el3__help_h
+#ifndef __el__help_h
+#define __el__help_h
 
 #include <iostream>
 
 #include "game.h"
 
-namespace el3 {
+#include "release.h"
+
+namespace PRJID {
 
 
 class Help {
@@ -14,8 +16,8 @@ public:
 
 static void controls();
 static void gameplay();
-static void goal(E_LevelType,bool level=false);
 
+static void hud();
 static void paused();
 static void title();
 
