@@ -1,5 +1,5 @@
-#ifndef __el3__menu_h
-#define __el3__menu_h
+#ifndef __el__menu_h
+#define __el__menu_h
 
 #include <iostream>
 #include <vector>
@@ -48,11 +48,11 @@ class Menu {
 	void handle(int id);
 	int scale;
 	C3 offset;
-	unsigned int font,font_selected;
+	bool smooth;
 public:
 
 	Menu();
-	Menu(C3 os);
+	Menu(int s,C3 os,bool sm=true);
 
 	bool isactive() { return current!=NULL; }
 
