@@ -1,10 +1,9 @@
 #include "random.h"
 
 #include <iostream>
-#include <cstdlib>
 
 
-namespace el3 {
+namespace PRJID {
 
 static bool seeded=false;
 
@@ -72,9 +71,16 @@ int Random::sget() {
 }
 
 int Random::sget(unsigned int below) {
+	if (below<=1) return 0;
 	return sget()%below;
 }
 
+int Random::sget(unsigned int above,unsigned int below) {
+	int r;
+	r=above;
+	r+=sget(below-above);
+	return r;
+}
 
 
 
