@@ -1,10 +1,11 @@
-#ifndef __el3__random_h
-#define __el3__random_h
+#ifndef __el__random_h
+#define __el__random_h
 
 #include <iostream>
 #include <vector>
 
-namespace el3 {
+#include "release.h"
+namespace PRJID {
 
 class Random {
 
@@ -18,6 +19,7 @@ public:
 
 	static int sget();
 	static int sget(unsigned int below);
+	static int sget(unsigned int above,unsigned int below);
 	static float sgetf();
 	static bool sboolean();
 	static int ssign();
