@@ -1,8 +1,9 @@
 
 
 #include "coordinate.h"
+#include "release.h"
 
-namespace el3 {
+namespace PRJID {
 
 void error();
 
@@ -26,5 +27,7 @@ void unlockmouse();
 void togglemouselock();
 bool ismouselocked();
 
-bool testspeed();
+void took_on();
+void took_off();
+
 } //namespace
